@@ -10,7 +10,6 @@ import (
 	"github.com/charmbracelet/lipgloss"
 	"github.com/goreleaser/goreleaser/pkg/context"
 	"github.com/spf13/cobra"
-	cobracompletefig "github.com/withfig/autocomplete-tools/integrations/cobra"
 )
 
 var (
@@ -99,7 +98,6 @@ Check out our website for more information, examples and documentation: https://
 		newDocsCmd().cmd,
 		newManCmd().cmd,
 		newSchemaCmd().cmd,
-		cobracompletefig.CreateCompletionSpecCommand(),
 	)
 	root.cmd = cmd
 	return root
