@@ -8,7 +8,7 @@ import (
 	"net/url"
 	"strconv"
 
-	"github.com/caarlos0/env/v9"
+	"github.com/caarlos0/env/v11"
 	"github.com/caarlos0/log"
 	"github.com/goreleaser/goreleaser/internal/tmpl"
 	"github.com/goreleaser/goreleaser/pkg/context"
@@ -53,8 +53,8 @@ func (p Pipe) Announce(ctx *context.Context) error {
 		return fmt.Errorf("discord: %w", err)
 	}
 
-	var cfg Config
-	if err = env.Parse(&cfg); err != nil {
+	cfg, err := env.ParseAs[Config]()
+	if err != nil {
 		return fmt.Errorf("discord: %w", err)
 	}
 
