@@ -103,6 +103,7 @@ func doRun(ctx *context.Context, fpm config.NFPM) error {
 		artifact.Or(
 			artifact.ByGoos("linux"),
 			artifact.ByGoos("ios"),
+			artifact.ByGoos("android"),
 		),
 	}
 	if len(fpm.Builds) > 0 {
@@ -144,9 +145,12 @@ func mergeOverrides(fpm config.NFPM, format string) (*config.NFPMOverridables, e
 
 const termuxFormat = "termux.deb"
 
-func isSupportedTermuxArch(arch string) bool {
-	for _, a := range []string{"amd64", "arm64", "386"} {
-		if strings.HasPrefix(arch, a) {
+func isSupportedTermuxArch(goos, goarch string) bool {
+	if goos != "android" {
+		return false
+	}
+	for _, arch := range []string{"amd64", "arm64", "386"} {
+		if strings.HasPrefix(goarch, arch) {
 			return true
 		}
 	}
@@ -155,18 +159,24 @@ func isSupportedTermuxArch(arch string) bool {
 
 // arch officially only supports x86_64.
 // however, there are unofficial ports for 686, arm64, and armv7
-func isSupportedArchlinuxArch(arch, arm string) bool {
-	if arch == "arm" && arm == "7" {
+func isSupportedArchlinuxArch(goarch, goarm string) bool {
+	if goarch == "arm" && goarm == "7" {
 		return true
 	}
-	for _, a := range []string{"amd64", "arm64", "386"} {
-		if strings.HasPrefix(arch, a) {
+	for _, arch := range []string{"amd64", "arm64", "386"} {
+		if strings.HasPrefix(goarch, arch) {
 			return true
 		}
 	}
 	return false
 }
 
+var termuxArchReplacer = strings.NewReplacer(
+	"386", "i686",
+	"amd64", "x86_64",
+	"arm64", "aarch64",
+)
+
 func create(ctx *context.Context, fpm config.NFPM, format string, artifacts []*artifact.Artifact) error {
 	// TODO: improve mips handling on nfpm
 	infoArch := artifacts[0].Goarch + artifacts[0].Goarm + artifacts[0].Gomips // key used for the ConventionalFileName et al
@@ -188,24 +198,25 @@ func create(ctx *context.Context, fpm config.NFPM, format string, artifacts []*a
 			return nil
 		}
 	case termuxFormat:
-		if !isSupportedTermuxArch(artifacts[0].Goarch) {
+		if !isSupportedTermuxArch(artifacts[0].Goos, artifacts[0].Goarch) {
 			log.Debugf("skipping termux.deb for %s as its not supported by termux", arch)
 			return nil
 		}
 
-		replacer := strings.NewReplacer(
-			"386", "i686",
-			"amd64", "x86_64",
-			"arm64", "aarch64",
-		)
-		infoArch = replacer.Replace(infoArch)
-		arch = replacer.Replace(arch)
+		infoArch = termuxArchReplacer.Replace(infoArch)
+		arch = termuxArchReplacer.Replace(arch)
+		infoPlatform = "linux"
 		fpm.Bindir = termuxPrefixedDir(fpm.Bindir)
 		fpm.Libdirs.Header = termuxPrefixedDir(fpm.Libdirs.Header)
 		fpm.Libdirs.CArchive = termuxPrefixedDir(fpm.Libdirs.CArchive)
 		fpm.Libdirs.CShared = termuxPrefixedDir(fpm.Libdirs.CShared)
 	}
 
+	if artifacts[0].Goos == "android" && format != termuxFormat {
+		log.Debugf("skipping android packaging as its not supported by %s", format)
+		return nil
+	}
+
 	overridden, err := mergeOverrides(fpm, format)
 	if err != nil {
 		return err
@@ -457,7 +468,7 @@ func create(ctx *context.Context, fpm config.NFPM, format string, artifacts []*a
 	}
 
 	if !strings.HasSuffix(packageFilename, ext) {
-		packageFilename = packageFilename + ext
+		packageFilename += ext
 	}
 
 	path := filepath.Join(ctx.Config.Dist, packageFilename)
