@@ -46,8 +46,9 @@ func TestMain(m *testing.M) {
 		os.Exit(1)
 	}
 
-	defer os.RemoveAll(keyring)
-	os.Exit(m.Run())
+	code := m.Run()
+	_ = os.RemoveAll(keyring)
+	os.Exit(code)
 }
 
 func TestDescription(t *testing.T) {
@@ -649,8 +650,7 @@ func testSign(
 
 	// run the pipeline
 	if expectedErrMsg != "" {
-		require.Error(tb, err)
-		require.Contains(tb, err.Error(), expectedErrMsg)
+		require.ErrorContains(tb, err, expectedErrMsg)
 		return
 	}
 
@@ -705,7 +705,7 @@ func testSign(
 		}),
 	)
 
-	wantFiles := append(artifacts, signaturePaths...)
+	wantFiles := append(artifacts, signaturePaths...) //nolint: gocritic
 	sort.Strings(wantFiles)
 	require.ElementsMatch(tb, wantFiles, gotFiles)
 
