@@ -9,8 +9,10 @@ import (
 	"github.com/goreleaser/goreleaser/internal/pipe/artifactory"
 	"github.com/goreleaser/goreleaser/internal/pipe/aur"
 	"github.com/goreleaser/goreleaser/internal/pipe/blob"
+	"github.com/goreleaser/goreleaser/internal/pipe/bluesky"
 	"github.com/goreleaser/goreleaser/internal/pipe/brew"
 	"github.com/goreleaser/goreleaser/internal/pipe/build"
+	"github.com/goreleaser/goreleaser/internal/pipe/changelog"
 	"github.com/goreleaser/goreleaser/internal/pipe/checksums"
 	"github.com/goreleaser/goreleaser/internal/pipe/chocolatey"
 	"github.com/goreleaser/goreleaser/internal/pipe/discord"
@@ -24,6 +26,7 @@ import (
 	"github.com/goreleaser/goreleaser/internal/pipe/milestone"
 	"github.com/goreleaser/goreleaser/internal/pipe/nfpm"
 	"github.com/goreleaser/goreleaser/internal/pipe/nix"
+	"github.com/goreleaser/goreleaser/internal/pipe/notary"
 	"github.com/goreleaser/goreleaser/internal/pipe/opencollective"
 	"github.com/goreleaser/goreleaser/internal/pipe/project"
 	"github.com/goreleaser/goreleaser/internal/pipe/reddit"
@@ -62,9 +65,11 @@ var Defaulters = []Defaulter{
 	snapshot.Pipe{},
 	release.Pipe{},
 	project.Pipe{},
+	changelog.Pipe{},
 	gomod.Pipe{},
 	build.Pipe{},
 	universalbinary.Pipe{},
+	notary.MacOS{},
 	upx.Pipe{},
 	sourcearchive.Pipe{},
 	archive.Pipe{},
@@ -100,4 +105,5 @@ var Defaulters = []Defaulter{
 	webhook.Pipe{},
 	chocolatey.Pipe{},
 	opencollective.Pipe{},
+	bluesky.Pipe{},
 }
